@@ -1,7 +1,10 @@
-/**
- * $Id: commons.h,v 1.2 2004/06/22 12:23:39 jklein Exp $
+/*
+ * $Id: commons.h,v 1.3 2004/06/24 00:08:35 jklein Exp $
  * $Author: jklein $
  * $Log: commons.h,v $
+ * Revision 1.3  2004/06/24 00:08:35  jklein
+ * added s_buffer_compare()
+ *
  * Revision 1.2  2004/06/22 12:23:39  jklein
  * correcting mistakes.
  *
@@ -27,7 +30,7 @@
 #endif
 
 
-/* all of primitive types for SC libraries. */
+/** all of primitive types for SC libraries. */
 typedef void * spointer;
 
 #if HAVE_STDBOOL_H
@@ -82,17 +85,29 @@ typedef float	sfloat;
 typedef double  sdouble;
 
 
-/* compare function for all SC libraries.
- * returns
- *  1 : v1 >  v2
- *  0 : v1 == v2
- * -1 : v1  < v2
+/**
+ * Scale$B%i%$%V%i%jCf$G;HMQ$5$l$kHf3S4X?t!#(B
+ * $BJV$jCM$O(Bp1$B$NJ}$,Bg$-$$$H$-$O@5$N?t!"Ey$7$$$H$-$O(B0$B!"(Bp2$B$NJ}$,Bg$-$$$H$-$O(B
+ * $BIi$N?t$rJV$7$^$9!#(B
+ * @see s_string_compare(), s_string_rcompare(), s_buffer_compare(),
+ *		s_buffer_rcompare(), s_pointer_compare()
  */
-typedef sint8 (*sc_compf_t)(const spointer, const spointer);
+typedef sint8 (*sc_compf_t)(const spointer p1, const spointer p2);
 
 
+/** (char *)$B$I$&$7$NHf3S$r9T$J$&!#(B */
 sint8 s_string_compare(const spointer, const spointer);
+
+/** (char *)$B$I$&$7$NHf3S$r9T$J$&$,!"JV$jCM$ODL>o$N5U$K$J$k!#(B */
 sint8 s_string_rcompare(const spointer, const spointer);
+
+/** sbuffer_t$B$I$&$7$NHf3S$r9T$J$&!#(B */
+sint8 s_buffer_compare(const spointer, const spointer);
+
+/** sbuffer_t$B$I$&$7$NHf3S$r9T$J$&$,!"JV$jCM$O5U$K$J$k!#(B */
+sint8 s_buffer_rcompare(const spointer, const spointer);
+
+/** $B%]%$%s%?$I$&$7$NHf3S$r9T$J$&!#(B */
 sint8 s_pointer_compare(const spointer, const spointer);
 
 #endif /* _SC_COMMONS_H_ */
