@@ -19,6 +19,7 @@
 
 #include "scale/commons.h"
 #include "scale/iterator.h"
+#include "scale/xarray.h"
 
 typedef struct _sc_linklist slist_t;
 typedef struct _sc_linklist_node slist_node_t;
@@ -53,8 +54,12 @@ spointer		s_list_get(slist_t *, size_t);
 spointer		s_list_remove(slist_t *, size_t);
 sint32			s_list_find(slist_t *, sc_compf_t, spointer);
 sboolean		s_list_join(slist_t *, slist_t *);
+void			s_list_sort(slist_t *, sc_compf_t);
 
 siterator_t *	s_list_iterator(slist_t *);
+sxarray_t *		s_list_xarray(void);
+sxarray_t *		s_list_attach_xarray(slist_t *);
+
 
 /* this is for debbuging.
  * or you can use this any time. */
