@@ -18,6 +18,8 @@
 
 #include "scale/commons.h"
 #include "scale/iterator.h"
+#include "scale/xarray.h"
+
 
 typedef struct _vector svector_t;
 
@@ -39,8 +41,11 @@ spointer		s_vector_get(svector_t *, size_t);
 spointer		s_vector_remove(svector_t *, size_t);
 sint32			s_vector_find(svector_t *, sc_compf_t, spointer);
 sboolean		s_vector_join(svector_t *, svector_t *);
+void			s_vector_sort(svector_t *, sc_compf_t);
 
 siterator_t *	s_vector_iterator(svector_t *);
+sxarray_t *		s_vector_xarray(void);
+sxarray_t *		s_vector_attach_xarray(svector_t *);
 
 
 #endif /* _SC_VECTOR_H_ */
