@@ -270,6 +270,17 @@ s_list_join(slist_t *dst, slist_t *src)
 }
 
 
+void
+s_list_sort(slist_t *list, sc_compf_t cmpf)
+{
+	/* not yet */
+}
+
+
+/***************************************************************************
+ * These functions are for siterator_t interface.
+ ***************************************************************************/
+
 
 typedef struct {
 	slist_node_t *next;
@@ -334,3 +345,115 @@ s_list_iterator(slist_t *list)
 
 	return itr;
 }
+
+
+
+
+/***************************************************************************
+ * These functions are for sxarray_t interface.
+ ***************************************************************************/
+
+
+#define __XARR_GET_LIST(__xarr) ((slist_t *)__xarr->listdata)
+
+
+static void
+_s_list_xarr_free(sxarray_t *xarr)
+{
+	slist_t *list = __XARR_GET_LIST(xarr);
+
+	if (xarr->is_origin)
+		s_list_free(list);
+	s_freen(xarr, sizeof(sxarray_t));
+}
+
+
+static size_t
+_s_list_xarr_size(sxarray_t *xarr)
+{
+	slist_t *list = __XARR_GET_LIST(xarr);
+	return s_list_size(list);
+}
+
+
+static void
+_s_list_xarr_add(sxarray_t *xarr, spointer contents)
+{
+	slist_t *list = __XARR_GET_LIST(xarr);
+	s_list_add(list, contents);
+}
+
+
+static spointer
+_s_list_xarr_get(sxarray_t *xarr, size_t ind)
+{
+	slist_t *list = __XARR_GET_LIST(xarr);
+	return s_list_get(list, ind);
+}
+
+
+static spointer
+_s_list_xarr_remove(sxarray_t *xarr, size_t ind)
+{
+	slist_t *list = __XARR_GET_LIST(xarr);
+	return s_list_remove(list, ind);
+}
+
+
+static sint32
+_s_list_xarr_find(sxarray_t *xarr, sc_compf_t cmpf, spointer contents)
+{
+	slist_t *list = __XARR_GET_LIST(xarr);
+	return s_list_find(list, cmpf, contents);
+}
+
+
+static siterator_t *
+_s_list_xarr_iterator(sxarray_t *xarr)
+{
+	slist_t *list = __XARR_GET_LIST(xarr);
+	return s_list_iterator(list);
+}
+
+
+static void
+_s_list_xarr_sort(sxarray_t *xarr, sc_compf_t cmpf)
+{
+	slist_t *list = __XARR_GET_LIST(xarr);
+	s_list_sort(list, cmpf);
+}
+
+
+
+
+sxarray_t *
+s_list_xarray(void)
+{
+	slist_t *list = s_list_alloc();
+	sxarray_t *xarr = s_list_attach_xarray(list);
+	xarr->is_origin = true;
+	return xarr;
+}
+
+
+sxarray_t *
+s_list_attach_xarray(slist_t *list)
+{
+	sxarray_t *xarr;
+
+	xarr = (sxarray_t *)s_malloc(sizeof(sxarray_t));
+	xarr->listdata = list;
+	xarr->free     = _s_list_xarr_free;
+	xarr->size     = _s_list_xarr_size;
+	xarr->add      = _s_list_xarr_add;
+	xarr->get      = _s_list_xarr_get;
+	xarr->remove   = _s_list_xarr_remove;
+	xarr->find     = _s_list_xarr_find;
+	xarr->iterator = _s_list_xarr_iterator;
+	xarr->sort     = _s_list_xarr_sort;
+
+	xarr->is_origin = false;
+	
+	return xarr;
+}
+
